@@ -48,7 +48,7 @@ class PageMiddleware(object):
             can_delete = site_setting.can_delete(user)
         else:
             can_edit = can_delete = False
-        page = utils.get_page(request.path)
+        page = utils.get_page(request.path_info)
         if page or can_edit:
             static_url = getattr(settings, 'STATIC_URL', settings.MEDIA_URL)
             context = {'page': page, 'STATIC_URL': static_url,
